@@ -14,7 +14,8 @@ import pprint
 import pickle
 from copy import deepcopy
 
-from default_metrics import metrics as d_metrics
+from althiqa.default_metrics import metrics as d_metrics
+
 def add_doc(m) :
     m['description'] = m['metric_function'].__doc__ 
     return m
@@ -24,7 +25,8 @@ from codecarbon import OfflineEmissionsTracker
 
 from sklearn.metrics import roc_auc_score, r2_score, accuracy_score, f1_score, balanced_accuracy_score, matthews_corrcoef
 
-from aiirw import AI_IRW
+from althiqa.aiirw import AI_IRW
+
 import copy
 
 
